@@ -2,7 +2,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 
     SPDX-FileCopyrightText: 2005 Richard Dale <Richard_Dale@tipitina.demon.co.uk>
-    SPDX-FileCopyrightText: 2006-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2006-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #include "rubycodecomment.h"
@@ -20,7 +20,7 @@ RubyCodeComment::~RubyCodeComment()
 
 QString RubyCodeComment::getNewEditorLine(int amount)
 {
-    QString line = getIndentationString(amount) + QLatin1String("# ");
+    QString line = getIndentationString(amount) + QStringLiteral("# ");
     return line;
 }
 
@@ -30,7 +30,7 @@ QString RubyCodeComment::unformatText(const QString & text, const QString & inde
     QString mytext = TextBlock::unformatText(text, indent);
 
     // now leading hash
-    mytext.remove(QRegExp(QLatin1String("^#\\s*")));
+    mytext.remove(QRegExp(QStringLiteral("^#\\s*")));
     return mytext;
 }
 
@@ -42,7 +42,7 @@ QString RubyCodeComment::toString() const
     if (getWriteOutText()) {
         QString indent = getIndentationString();
         QString endLine = getNewLineEndingChars();
-        output.append(formatMultiLineText(getText(), indent + QLatin1String("# "), endLine + endLine));
+        output.append(formatMultiLineText(getText(), indent + QStringLiteral("# "), endLine + endLine));
     }
 
     return output;
