@@ -41,9 +41,10 @@ StateWidget::StateWidget(UMLScene * scene, StateType stateType, Uml::ID::Type id
 {
     setStateType(stateType);
     m_drawVertical = true;
-    m_Text = QLatin1String("State");
-    QSizeF size = minimumSize();
-    setSize(size.width(), size.height());
+    // Set non zero size to avoid crash on painting.
+    // We cannot call the reimplemented method minimumSize() in the constructor
+    // because the vtable is not yet finalized (i.e. dynamic dispatch does not work).
+    setSize(15, 15);
 }
 
 /**
@@ -149,12 +150,12 @@ void StateWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *optio
             painter->setFont(UMLWidget::font());
             const QFontMetrics &fm = getFontMetrics(FT_NORMAL);
             const int fontHeight  = fm.lineSpacing() / 2;
-            const int xStar = fm.boundingRect(QLatin1String("H")).width();
+            const int xStar = fm.boundingRect(QStringLiteral("H")).width();
             const int yStar = fontHeight / 4;
             painter->drawText((w / 6),
-                       (h / 4) + fontHeight, QLatin1String("H"));
+                       (h / 4) + fontHeight, QStringLiteral("H"));
             painter->drawText((w / 6) + xStar,
-                       (h / 4) + fontHeight - yStar, QLatin1String("*"));
+                       (h / 4) + fontHeight - yStar, QStringLiteral("*"));
         }
         break;
     case StateWidget::ShallowHistory:
@@ -166,7 +167,7 @@ void StateWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *optio
             const QFontMetrics &fm = getFontMetrics(FT_NORMAL);
             const int fontHeight  = fm.lineSpacing() / 2;
             painter->drawText((w / 6),
-                       (h / 4) + fontHeight, QLatin1String("H"));
+                       (h / 4) + fontHeight, QStringLiteral("H"));
         }
         break;
     case StateWidget::Choice:
@@ -222,7 +223,7 @@ void StateWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *optio
  */
 QSizeF StateWidget::minimumSize() const
 {
-    int width = 10, height = 10;
+    int width = 15, height = 15;
     switch (m_stateType) {
         case StateWidget::Normal:
         {
@@ -505,20 +506,20 @@ bool StateWidget::showPropertiesDialog()
  */
 void StateWidget::saveToXMI(QXmlStreamWriter& writer)
 {
-    writer.writeStartElement(QLatin1String("statewidget"));
+    writer.writeStartElement(QStringLiteral("statewidget"));
     UMLWidget::saveToXMI(writer);
-    writer.writeAttribute(QLatin1String("statename"), m_Text);
-    writer.writeAttribute(QLatin1String("documentation"), m_Doc);
-    writer.writeAttribute(QLatin1String("statetype"), QString::number(m_stateType));
+    writer.writeAttribute(QStringLiteral("statename"), m_Text);
+    writer.writeAttribute(QStringLiteral("documentation"), m_Doc);
+    writer.writeAttribute(QStringLiteral("statetype"), QString::number(m_stateType));
     if (m_stateType == Fork || m_stateType == Join)
-        writer.writeAttribute(QLatin1String("drawvertical"), QString::number(m_drawVertical));
+        writer.writeAttribute(QStringLiteral("drawvertical"), QString::number(m_drawVertical));
     //save states activities
-    writer.writeStartElement(QLatin1String("Activities"));
+    writer.writeStartElement(QStringLiteral("Activities"));
 
     QStringList::Iterator end(m_Activities.end());
     for (QStringList::Iterator it(m_Activities.begin()); it != end; ++it) {
-        writer.writeStartElement(QLatin1String("Activity"));
-        writer.writeAttribute(QLatin1String("name"), *it);
+        writer.writeStartElement(QStringLiteral("Activity"));
+        writer.writeAttribute(QStringLiteral("name"), *it);
         writer.writeEndElement();
     }
     writer.writeEndElement();            // Activities
@@ -532,22 +533,22 @@ bool StateWidget::loadFromXMI(QDomElement & qElement)
 {
     if(!UMLWidget::loadFromXMI(qElement))
         return false;
-    m_Text = qElement.attribute(QLatin1String("statename"));
-    m_Doc = qElement.attribute(QLatin1String("documentation"));
-    QString type = qElement.attribute(QLatin1String("statetype"), QLatin1String("1"));
+    m_Text = qElement.attribute(QStringLiteral("statename"));
+    m_Doc = qElement.attribute(QStringLiteral("documentation"));
+    QString type = qElement.attribute(QStringLiteral("statetype"), QStringLiteral("1"));
     setStateType((StateType)type.toInt());
     setAspectRatioMode();
-    QString drawVertical = qElement.attribute(QLatin1String("drawvertical"), QLatin1String("1"));
+    QString drawVertical = qElement.attribute(QStringLiteral("drawvertical"), QStringLiteral("1"));
     m_drawVertical = (bool)drawVertical.toInt();
     //load states activities
     QDomNode node = qElement.firstChild();
     QDomElement tempElement = node.toElement();
-    if(!tempElement.isNull() && tempElement.tagName() == QLatin1String("Activities")) {
+    if(!tempElement.isNull() && tempElement.tagName() == QStringLiteral("Activities")) {
         QDomNode node = tempElement.firstChild();
         QDomElement activityElement = node.toElement();
         while(!activityElement.isNull()) {
-            if(activityElement.tagName() == QLatin1String("Activity")) {
-                QString name = activityElement.attribute(QLatin1String("name"));
+            if(activityElement.tagName() == QStringLiteral("Activity")) {
+                QString name = activityElement.attribute(QStringLiteral("name"));
                 if(!name.isEmpty())
                     m_Activities.append(name);
             }//end if
